@@ -7,7 +7,7 @@ import logging
 from datetime import datetime
 
 from quark.Objects.tableobject import TableObject
-from quark.Objects.variableobject import RegisterObject
+from quark.Objects.registerobject import RegisterObject
 
 MAX_REG_COUNT = 40
 TIMESTAMPS = datetime.now().strftime('%Y-%m-%d')
@@ -38,6 +38,8 @@ class PyEval:
             "invoke-virtual": self.INVOKE_VIRTUAL,
             "invoke-direct": self.INVOKE_DIRECT,
             "invoke-static": self.INVOKE_STATIC,
+            "invoke-virtual/range": self.INVOKE_VIRTUAL_RANGE,
+            "invoke-interface": self.INVOKE_INTERFACE,
             # move-result-kind
             "move-result": self.MOVE_RESULT,
             "move-result-wide": self.MOVE_RESULT_WIDE,
@@ -153,6 +155,22 @@ class PyEval:
         """
         self._invoke(instruction)
 
+    @logger
+    def INVOKE_VIRTUAL_RANGE(self, instruction):
+        """
+        invoke-virtual/range { parameters }, methodtocall
+        Invokes a virtual-range method with parameters.
+        """
+        self._invoke(instruction)
+
+    @logger
+    def INVOKE_INTERFACE(self, instruction):
+        """
+        invoke-interface { parameters }, methodtocall
+        Invokes a interface method with parameters.
+        """
+        self._invoke(instruction)
+
     @logger
     def MOVE_RESULT(self, instruction):
         """
